pub struct PackageWrapperV0_5_0 {
pub meta: PackageMetadata,
pub imports: Vec<PackageImport>,
pub types: MetadataTypesMapWrapper,
pub states: BTreeMap<String, TypedState>,
pub functions: Vec<Function>,
pub dev: Option<DevConfig>,
}Fields
meta: PackageMetadataimports: Vec<PackageImport>types: MetadataTypesMapWrapperstates: BTreeMap<String, TypedState>functions: Vec<Function>dev: Option<DevConfig>Trait Implementations
Sourceimpl Clone for PackageWrapperV0_5_0
impl Clone for PackageWrapperV0_5_0
Sourcefn clone(&self) -> PackageWrapperV0_5_0
fn clone(&self) -> PackageWrapperV0_5_0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackageWrapperV0_5_0
impl Debug for PackageWrapperV0_5_0
Sourceimpl Default for PackageWrapperV0_5_0
impl Default for PackageWrapperV0_5_0
Sourcefn default() -> PackageWrapperV0_5_0
fn default() -> PackageWrapperV0_5_0
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PackageWrapperV0_5_0
impl<'de> Deserialize<'de> for PackageWrapperV0_5_0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PackageWrapperV0_5_0
impl JsonSchema for PackageWrapperV0_5_0
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PackageWrapperV0_5_0
impl RefUnwindSafe for PackageWrapperV0_5_0
impl Send for PackageWrapperV0_5_0
impl Sync for PackageWrapperV0_5_0
impl Unpin for PackageWrapperV0_5_0
impl UnwindSafe for PackageWrapperV0_5_0